/*
     This file is part of GNUnet

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * Policy interface. This is the interface to the C part of the policy.
 * @author Christian Grothoff
 * @file include/policy.h
 **/

#ifndef POLICY_H
#define POLICY_H

#include "config.h"
#include "server/coreapi.h"

/* ****************** functions ******************** */

void initPolicy();

void donePolicy();

/**
 * A new packet is supposed to be send out. Should it be
 * dropped because the load is too high?
 * <p>
 * @param priority the highest priority of contents in the packet
 * @return OK if the packet should be handled, SYSERR if the packet should be dropped.
 **/
int outgoingCheck(unsigned int priority);

/**
 * A new packet is coming in. The question is, if we should
 * have a look at it at all (incl. decryption). The sender
 * is known. 
 * <p>
 * The policy must decide if we should drop the packet. The
 * reason may be that we don't trust the host or that the load
 * is to high (or both or a combination). 
 * <p>
 * @param senderIdentity the identity of the sender
 * @return OK if the packet should be handled, SYSERR if the packet should be dropped.
 **/
int incomingCheck(const HostIdentity * senderIdentity);

int isWhitelisted(struct in_addr ip);

#endif
/* end of policy.h */
